"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.tsx
var src_exports = {};
__export(src_exports, {
  usePdf: () => usePdf
});
module.exports = __toCommonJS(src_exports);
var import_react = require("react");
var pdfjs = __toESM(require("pdfjs-dist"), 1);
function isFunction(value) {
  return typeof value === "function";
}
var pdfStyleDefault = {
  display: "block",
  "margin-left": "auto",
  "margin-right": "auto",
  "margin-bottom": "1em",
  "border-radius": "10px",
  border: "2px solid",
  "align-content": "center",
  "align-items": "center",
  "box-shadow": "rgba(22, 31, 39, 0.42) 0px 60px 123px -25px, rgba(19, 26, 32, 0.08) 0px 35px 75px -35px",
  "border-color": "rgb(213, 220, 226) rgb(213, 220, 226) rgb(184, 194, 204)"
};
var usePdf = ({
  pdfLocation,
  file,
  onDocumentLoadSuccess,
  onDocumentLoadFail,
  onInvalidLocation,
  scale = 0.9,
  rotate = 0,
  cMapUrl,
  cMapPacked,
  workerSrc = `//cdnjs.cloudflare.com/ajax/libs/pdf.js/${pdfjs.version}/pdf.worker.mjs`,
  withCredentials = false,
  className = "",
  useDefaultStyle = true
}) => {
  const [pdfDocument, setPdfDocument] = (0, import_react.useState)();
  const [allPdfPages, setAllPdfPages] = (0, import_react.useState)();
  const [pdfLocationDisplay, setPdfLocationDisplay] = (0, import_react.useState)();
  const onDocumentLoadSuccessRef = (0, import_react.useRef)(onDocumentLoadSuccess);
  const onDocumentLoadFailRef = (0, import_react.useRef)(onDocumentLoadFail);
  const onInvalidLocationRef = (0, import_react.useRef)(onInvalidLocation);
  (0, import_react.useEffect)(() => {
    onDocumentLoadSuccessRef.current = onDocumentLoadSuccess;
  }, [onDocumentLoadSuccess]);
  (0, import_react.useEffect)(() => {
    onDocumentLoadFailRef.current = onDocumentLoadFail;
  }, [onDocumentLoadFail]);
  (0, import_react.useEffect)(() => {
    onInvalidLocationRef.current = onInvalidLocation;
  }, [onInvalidLocation]);
  (0, import_react.useEffect)(() => {
    pdfjs.GlobalWorkerOptions.workerSrc = workerSrc;
  }, [workerSrc]);
  (0, import_react.useEffect)(() => {
    const config = { url: file, withCredentials };
    if (cMapUrl) {
      config.cMapUrl = cMapUrl;
      config.cMapPacked = cMapPacked;
    }
    pdfjs.getDocument(config).promise.then(
      (loadedPdfDocument) => {
        setPdfDocument(loadedPdfDocument);
        if (isFunction(onDocumentLoadSuccessRef.current)) {
          onDocumentLoadSuccessRef.current(loadedPdfDocument);
        }
      },
      () => {
        if (isFunction(onDocumentLoadFailRef.current)) {
          onDocumentLoadFailRef.current();
        }
      }
    );
  }, [file, withCredentials, cMapUrl, cMapPacked]);
  (0, import_react.useEffect)(() => {
    const getPages = async (pdf) => {
      if (!pdf) {
        return [];
      }
      let pages = [];
      for (let i = 1; i <= pdf.numPages; i++) {
        const page = await pdf.getPage(i);
        pages.push(page);
      }
      return pages;
    };
    const processPages = (pages) => {
      if (!pdfLocationDisplay) {
        return;
      }
      for (const page of pages) {
        const rotation = rotate === 0 ? page.rotate : page.rotate + rotate;
        const viewport = page.getViewport({ scale, rotation });
        let canvas = pdfLocationDisplay?.appendChild(
          document.createElement("canvas")
        );
        if (!canvas) {
          continue;
        }
        if (useDefaultStyle) {
          for (const [key, value] of Object.entries(pdfStyleDefault)) {
            canvas.style.setProperty(key, value);
          }
        }
        if (className) {
          canvas.className = className;
        }
        const canvasContext = canvas?.getContext("2d");
        if (!canvasContext) {
          return;
        }
        canvas.height = viewport.height * window.devicePixelRatio;
        canvas.width = viewport.width * window.devicePixelRatio;
        canvasContext.scale(window.devicePixelRatio, window.devicePixelRatio);
        page.render({ canvasContext, viewport });
      }
    };
    const drawPDFPages = async () => {
      if (!pdfDocument) {
        return;
      }
      if (!pdfLocationDisplay) {
        return;
      }
      pdfLocationDisplay.innerHTML = "";
      const allPages = await getPages(pdfDocument);
      setAllPdfPages(allPages);
      processPages(allPages);
    };
    const element = document.getElementById(pdfLocation);
    if (element) {
      setPdfLocationDisplay(element);
    } else {
      console.log("=== cannot find pdf location:", pdfLocation);
      if (isFunction(onInvalidLocationRef.current)) {
        onInvalidLocationRef.current();
        return;
      }
    }
    if (pdfDocument) {
      drawPDFPages();
    }
  }, [
    pdfLocation,
    pdfDocument,
    rotate,
    scale,
    useDefaultStyle,
    className,
    pdfLocationDisplay
  ]);
  return { allPdfPages, pdfDocument };
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  usePdf
});
